@@ -1,8 +1,7 @@
 #' @export
 #' @importFrom dplyr select
 select.tbl_graph <- function(.data, ...) {
-  .graph_context$set(.data)
-  on.exit(.graph_context$clear())
+  .register_graph_context(.data)
   d_tmp <- as_tibble(.data)
   d_tmp <- select(d_tmp, ...)
   set_graph_data(.data, d_tmp)
